@@ -1,4 +1,5 @@
 import requests
+import toml
 from requests.adapters import HTTPAdapter, Retry
 
 # Local import
@@ -35,7 +36,7 @@ class PyTriliumClient:
             logger_name="PyTriliumClient",
             log_file_name="PyTriliumClient.log",
             debug=debug,
-            create_log_file=True,
+            create_log_file=False,
         )
 
         # The valid response codes that can come from Triliu
@@ -45,7 +46,9 @@ class PyTriliumClient:
     def make_requests_session(self) -> None:
         """Creates a requests session with the token and user agent header."""
         self.session = requests.Session()
-        self.session.headers.update({"User-Agent": "PyTriliumClient/1.0.6"})
+
+        # Version here
+        self.session.headers.update({"User-Agent": f"pytrilium/{self.get_version()}"})
         #self.session.headers.update({"Content-Type": "application/json"})
 
         # Set up retry logic
@@ -125,3 +128,29 @@ class PyTriliumClient:
             raise ValueError(
                 f"Invalid response code: {str(resp.status_code)}, response text: {resp.text}. Response code should be one of {self.valid_response_codes}. Please check your Trilium, URL, and token."
             )
+
+    def get_app_info(self) -> dict:
+        """Gets the app info from the Trilium API.
+
+        Returns
+        -------
+        dict
+            The app info from the Trilium API.
+        """
+        return self.make_request("/app-info").json()
+    
+    def get_pyproject_toml(self) -> dict:
+        """Load the pyproject.toml file. This should not be called manually."""
+        import toml
+        with open("pyproject.toml", "r") as f:
+            return toml.load(f)
+
+    def get_version(self) -> str:
+        """Gets the version of the PyTriliumClient.
+
+        Returns
+        -------
+        str
+            The version of the PyTriliumClient.
+        """
+        return self.get_pyproject_toml()["project"]["version"]
\ No newline at end of file
